You should consider this protocol an implementation detail for now.
You should consider this protocol an implementation detail for now.
(-add-index idx p kind)(-del-index idx p kind)(-elements idx)(-get-eq idx p)(-get-sort idx p)(-get-uniq idx p)(-id-element-pairs idx)(-rewrap idx auto)You should consider this protocol an implementation detail for now.
You should consider this protocol an implementation detail for now.
(-predv this)(-prop this)You should consider this protocol an implementation detail for now.
You should consider this protocol an implementation detail for now.
(-property this element)You should consider this protocol an implementation detail for now.
You should consider this protocol an implementation detail for now.
(-unwrap coll)You should consider this protocol an implementation detail for now.
You should consider this protocol an implementation detail for now.
(-wrap coll auto)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |